@@ -656,13 +656,17 @@ class Tree(treemixin.DragAndDrop, customtreectrl.CustomTreeCtrl, utils.RideEvent
                 self.CheckItem(t, checked=False)
         self._for_all_tests(self._root, foo)
 
-
     def SelectFailedTests(self, item):
         def func(t):
             # FIXME: This information should be in domain model!
             self.CheckItem(t, checked=(self.GetItemImage(t) == FAILED_IMAGE_INDEX))
         self._for_all_tests(item, func)
 
+    def SelectPassedTests(self, item):
+        def func(t):
+            self.CheckItem(t, checked=(self.GetItemImage(t) == PASSED_IMAGE_INDEX))
+        self._for_all_tests(item, func)
+
     def OnTreeItemChecked(self, event):
         node = event.GetItem()
         handler = self._controller.get_handler(node=node)
